@@ -22,7 +22,6 @@
 #define GEDIT_APP_PRIVATE_H
 
 #include "gedit-app.h"
-#include "gedit-metadata-manager.h"
 #include "gedit-menu-extension.h"
 
 G_BEGIN_DECLS
@@ -35,16 +34,12 @@ GtkPrintSettings	*_gedit_app_get_default_print_settings	(GeditApp         *app);
 void			 _gedit_app_set_default_print_settings	(GeditApp         *app,
 								 GtkPrintSettings *settings);
 
-GeditMetadataManager	*_gedit_app_get_metadata_manager	(GeditApp  *app);
-
 GMenuModel		*_gedit_app_get_hamburger_menu		(GeditApp  *app);
 
 GMenuModel		*_gedit_app_get_notebook_menu		(GeditApp  *app);
 
 GMenuModel		*_gedit_app_get_tab_width_menu		(GeditApp  *app);
 
-GMenuModel		*_gedit_app_get_line_col_menu		(GeditApp  *app);
-
 GeditMenuExtension	*_gedit_app_extend_menu			(GeditApp    *app,
 								 const gchar *extension_point);
 
