@@ -28,9 +28,8 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gio/gio.h>
 #include <libpeas/peas-extension-set.h>
-#include <gtksourceview/gtksource.h>
+#include <tepl/tepl.h>
 
 #include "gedit-commands-private.h"
 #include "gedit-notebook.h"
@@ -45,10 +44,6 @@
 #include "gedit-preferences-dialog.h"
 #include "gedit-tab.h"
 
-#ifndef ENABLE_GVFS_METADATA
-#include "gedit-metadata-manager.h"
-#endif
-
 #define GEDIT_PAGE_SETUP_FILE		"gedit-page-setup"
 #define GEDIT_PRINT_SETTINGS_FILE	"gedit-print-settings"
 
@@ -56,22 +51,16 @@ typedef struct
 {
 	GeditPluginsEngine *engine;
 
-#ifndef ENABLE_GVFS_METADATA
-	GeditMetadataManager *metadata_manager;
-#endif
-
 	GtkCssProvider     *theme_provider;
 
 	GtkPageSetup      *page_setup;
 	GtkPrintSettings  *print_settings;
 
-	GSettings         *ui_settings;
 	GSettings         *window_settings;
 
 	GMenuModel        *hamburger_menu;
 	GMenuModel        *notebook_menu;
 	GMenuModel        *tab_width_menu;
-	GMenuModel        *line_col_menu;
 
 	PeasExtensionSet  *extensions;
 
@@ -154,11 +143,6 @@ gedit_app_dispose (GObject *object)
 
 	priv = gedit_app_get_instance_private (GEDIT_APP (object));
 
-#ifndef ENABLE_GVFS_METADATA
-	g_clear_object (&priv->metadata_manager);
-#endif
-
-	g_clear_object (&priv->ui_settings);
 	g_clear_object (&priv->window_settings);
 
 	g_clear_object (&priv->page_setup);
@@ -181,55 +165,58 @@ gedit_app_dispose (GObject *object)
 	g_clear_object (&priv->hamburger_menu);
 	g_clear_object (&priv->notebook_menu);
 	g_clear_object (&priv->tab_width_menu);
-	g_clear_object (&priv->line_col_menu);
 
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
 
 static gchar *
-gedit_app_help_link_id_impl (GeditApp    *app,
-                             const gchar *name,
-                             const gchar *link_id)
+gedit_app_get_help_uri_impl (GeditApp    *app,
+                             const gchar *name_of_user_manual,
+                             const gchar *link_id_within_user_manual)
 {
-	if (link_id)
+	if (link_id_within_user_manual != NULL)
 	{
-		return g_strdup_printf ("help:%s/%s", name, link_id);
+		return g_strdup_printf ("help:%s/%s",
+					name_of_user_manual,
+					link_id_within_user_manual);
 	}
 	else
 	{
-		return g_strdup_printf ("help:%s", name);
+		return g_strdup_printf ("help:%s", name_of_user_manual);
 	}
 }
 
 static gboolean
 gedit_app_show_help_impl (GeditApp    *app,
-                          GtkWindow   *parent,
-                          const gchar *name,
-                          const gchar *link_id)
+                          GtkWindow   *parent_window,
+                          const gchar *name_of_user_manual,
+                          const gchar *link_id_within_user_manual)
 {
-	GError *error = NULL;
+	gchar *uri;
 	gboolean ret;
-	gchar *link;
+	GError *error = NULL;
 
-	if (name == NULL)
+	if (name_of_user_manual == NULL)
 	{
-		name = "gedit";
+		name_of_user_manual = "gedit";
 	}
 
-	link = GEDIT_APP_GET_CLASS (app)->help_link_id (app, name, link_id);
+	uri = GEDIT_APP_GET_CLASS (app)->get_help_uri (app,
+						       name_of_user_manual,
+						       link_id_within_user_manual);
 
-	ret = gtk_show_uri_on_window (GTK_WINDOW (parent),
-	                    link,
-	                    GDK_CURRENT_TIME,
-	                    &error);
+	ret = gtk_show_uri_on_window (parent_window,
+				      uri,
+				      GDK_CURRENT_TIME,
+				      &error);
 
-	g_free (link);
+	g_free (uri);
 
 	if (error != NULL)
 	{
 		GtkWidget *dialog;
 
-		dialog = gtk_message_dialog_new (parent,
+		dialog = gtk_message_dialog_new (parent_window,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_CLOSE,
@@ -650,16 +637,30 @@ show_menubar (void)
 	return result;
 }
 
+static void
+init_tepl_settings (void)
+{
+	GeditSettings *gedit_settings;
+	GSettings *editor_settings;
+	TeplSettings *tepl_settings;
+
+	gedit_settings = _gedit_settings_get_singleton ();
+	editor_settings = _gedit_settings_peek_editor_settings (gedit_settings);
+
+	tepl_settings = tepl_settings_get_singleton ();
+
+	tepl_settings_provide_font_settings (tepl_settings,
+					     editor_settings,
+					     GEDIT_SETTINGS_USE_DEFAULT_FONT,
+					     GEDIT_SETTINGS_EDITOR_FONT);
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
 	GeditAppPrivate *priv;
 	GtkCssProvider *css_provider;
 	GtkSourceStyleSchemeManager *manager;
-#ifndef ENABLE_GVFS_METADATA
-	const gchar *cache_dir;
-	gchar *metadata_filename;
-#endif
 
 	priv = gedit_app_get_instance_private (GEDIT_APP (application));
 
@@ -671,17 +672,10 @@ gedit_app_startup (GApplication *application)
 
 	setup_theme_extensions (GEDIT_APP (application));
 
-#ifndef ENABLE_GVFS_METADATA
-	cache_dir = gedit_dirs_get_user_cache_dir ();
-	metadata_filename = g_build_filename (cache_dir, "gedit-metadata.xml", NULL);
-	priv->metadata_manager = gedit_metadata_manager_new (metadata_filename);
-	g_free (metadata_filename);
-#endif
-
 	/* Load/init settings */
 	_gedit_settings_get_singleton ();
-	priv->ui_settings = g_settings_new ("org.gnome.gedit.preferences.ui");
 	priv->window_settings = g_settings_new ("org.gnome.gedit.state.window");
+	init_tepl_settings ();
 
 	g_action_map_add_action_entries (G_ACTION_MAP (application),
 	                                 app_entries,
@@ -698,7 +692,6 @@ gedit_app_startup (GApplication *application)
 
 	priv->notebook_menu = get_menu_model (GEDIT_APP (application), "notebook-menu");
 	priv->tab_width_menu = get_menu_model (GEDIT_APP (application), "tab-width-menu");
-	priv->line_col_menu = get_menu_model (GEDIT_APP (application), "line-col-menu");
 
 	/* Accelerators */
 	add_accelerator (GTK_APPLICATION (application), "app.new-window", "<Primary>N");
@@ -1138,10 +1131,6 @@ gedit_app_shutdown (GApplication *app)
 	save_page_setup (GEDIT_APP (app));
 	save_print_settings (GEDIT_APP (app));
 
-	/* GTK+ can still hold references to some gedit objects, for example
-	 * GeditDocument for the clipboard. So the metadata-manager should be
-	 * shutdown after.
-	 */
 	G_APPLICATION_CLASS (gedit_app_parent_class)->shutdown (app);
 }
 
@@ -1199,7 +1188,7 @@ gedit_app_class_init (GeditAppClass *klass)
 	app_class->shutdown = gedit_app_shutdown;
 
 	klass->show_help = gedit_app_show_help_impl;
-	klass->help_link_id = gedit_app_help_link_id_impl;
+	klass->get_help_uri = gedit_app_get_help_uri_impl;
 	klass->set_window_title = gedit_app_set_window_title_impl;
 	klass->create_window = gedit_app_create_window_impl;
 }
@@ -1281,10 +1270,15 @@ load_print_settings (GeditApp *app)
 static void
 gedit_app_init (GeditApp *app)
 {
+	TeplApplication *tepl_app;
+
 	g_set_application_name ("gedit");
 	gtk_window_set_default_icon_name ("org.gnome.gedit");
 
 	g_application_add_main_option_entries (G_APPLICATION (app), options);
+
+	tepl_app = tepl_application_get_from_gtk_application (GTK_APPLICATION (app));
+	tepl_application_handle_metadata (tepl_app);
 }
 
 /**
@@ -1437,16 +1431,50 @@ gedit_app_get_views (GeditApp *app)
 	return res;
 }
 
+/**
+ * gedit_app_show_help:
+ * @app: a #GeditApp.
+ * @parent_window: (nullable): the #GtkWindow where the request originates from.
+ * @name_of_user_manual: (nullable): %NULL for gedit's user manual, otherwise
+ *   the name of another user manual (e.g., one from another application).
+ * @link_id_within_user_manual: (nullable): a link ID within the user manual, or
+ *   %NULL to show the start page.
+ *
+ * To show the user manual.
+ *
+ * As a useful information to know, the gedit user documentation is currently
+ * written in Mallard. As such, this functionality can easily be tested with
+ * Yelp on Linux:
+ *
+ * With @name_of_user_manual and @link_id_within_user_manual both %NULL, it is
+ * equivalent to:
+ *
+ * `$ yelp 'help:gedit'`
+ *
+ * With @link_id_within_user_manual set to `"gedit-replace"` (a Mallard page
+ * id):
+ *
+ * `$ yelp 'help:gedit/gedit-replace'`
+ *
+ * It is also possible to refer to a section id within a page id, for example:
+ *
+ * `$ yelp 'help:gedit/gedit-spellcheck#dict'`
+ *
+ * Returns: whether the operation was successful.
+ */
 gboolean
 gedit_app_show_help (GeditApp    *app,
-                     GtkWindow   *parent,
-                     const gchar *name,
-                     const gchar *link_id)
+                     GtkWindow   *parent_window,
+                     const gchar *name_of_user_manual,
+                     const gchar *link_id_within_user_manual)
 {
 	g_return_val_if_fail (GEDIT_IS_APP (app), FALSE);
-	g_return_val_if_fail (parent == NULL || GTK_IS_WINDOW (parent), FALSE);
+	g_return_val_if_fail (parent_window == NULL || GTK_IS_WINDOW (parent_window), FALSE);
 
-	return GEDIT_APP_GET_CLASS (app)->show_help (app, parent, name, link_id);
+	return GEDIT_APP_GET_CLASS (app)->show_help (app,
+						     parent_window,
+						     name_of_user_manual,
+						     link_id_within_user_manual);
 }
 
 void
@@ -1594,25 +1622,6 @@ _gedit_app_set_default_print_settings (GeditApp         *app,
 	priv->print_settings = g_object_ref (settings);
 }
 
-
-GeditMetadataManager *
-_gedit_app_get_metadata_manager (GeditApp *app)
-{
-#ifndef ENABLE_GVFS_METADATA
-	GeditAppPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
-
-	priv = gedit_app_get_instance_private (app);
-
-	return priv->metadata_manager;
-#else
-	g_assert_not_reached ();
-	return NULL;
-#endif
-}
-
-
 GMenuModel *
 _gedit_app_get_hamburger_menu (GeditApp *app)
 {
@@ -1649,18 +1658,6 @@ _gedit_app_get_tab_width_menu (GeditApp *app)
 	return priv->tab_width_menu;
 }
 
-GMenuModel *
-_gedit_app_get_line_col_menu (GeditApp *app)
-{
-	GeditAppPrivate *priv;
-
-	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
-
-	priv = gedit_app_get_instance_private (app);
-
-	return priv->line_col_menu;
-}
-
 GeditMenuExtension *
 _gedit_app_extend_menu (GeditApp    *app,
                         const gchar *extension_point)
