@@ -36,7 +36,6 @@
 #include "gedit-tab.h"
 #include "gedit-tab-private.h"
 #include "gedit-window.h"
-#include "gedit-window-private.h"
 #include "gedit-notebook.h"
 #include "gedit-statusbar.h"
 #include "gedit-utils.h"
@@ -123,6 +122,7 @@ load_file_list (GeditWindow             *window,
 	gboolean jump_to = TRUE; /* Whether to jump to the new tab */
 	const GSList *l;
 	gint num_loaded_files = 0;
+	GeditStatusbar *statusbar;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -242,31 +242,31 @@ load_file_list (GeditWindow             *window,
 
 	loaded_files = g_slist_reverse (loaded_files);
 
+	statusbar = GEDIT_STATUSBAR (gedit_window_get_statusbar (window));
+
 	if (num_loaded_files == 1)
 	{
 		GeditDocument *doc;
-		gchar *uri_for_display;
+		gchar *full_name;
 
 		g_return_val_if_fail (tab != NULL, loaded_files);
 
 		doc = gedit_tab_get_document (tab);
-		uri_for_display = _gedit_document_get_uri_for_display (doc);
+		full_name = tepl_file_get_full_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 
-		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-					       window->priv->generic_message_cid,
-					       _("Loading file “%s”\342\200\246"),
-					       uri_for_display);
+		_gedit_statusbar_flash_generic_message (statusbar,
+							_("Loading file “%s”\342\200\246"),
+							full_name);
 
-		g_free (uri_for_display);
+		g_free (full_name);
 	}
 	else
 	{
-		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-					       window->priv->generic_message_cid,
-					       ngettext ("Loading %d file\342\200\246",
-							 "Loading %d files\342\200\246",
-							 num_loaded_files),
-					       num_loaded_files);
+		_gedit_statusbar_flash_generic_message (statusbar,
+							ngettext ("Loading %d file\342\200\246",
+								  "Loading %d files\342\200\246",
+								  num_loaded_files),
+							num_loaded_files);
 	}
 
 	g_slist_free (files_to_load);
@@ -624,6 +624,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 	GtkSourceCompressionType compression_type;
 	GtkSourceCompressionType current_compression_type;
 	const GtkSourceEncoding *encoding;
+	GeditStatusbar *statusbar;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -672,10 +673,10 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 	parse_name = g_file_get_parse_name (location);
 
-	gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-				       window->priv->generic_message_cid,
-				       _("Saving file “%s”\342\200\246"),
-				       parse_name);
+	statusbar = GEDIT_STATUSBAR (gedit_window_get_statusbar (window));
+	_gedit_statusbar_flash_generic_message (statusbar,
+						_("Saving file “%s”\342\200\246"),
+						parse_name);
 
 	g_free (parse_name);
 
@@ -844,7 +845,7 @@ save_as_tab_async (GeditTab            *tab,
 		gedit_file_chooser_dialog_set_current_folder (save_dialog, default_folder);
 		g_object_unref (default_folder);
 
-		docname = gedit_document_get_short_name_for_display (doc);
+		docname = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 		gedit_file_chooser_dialog_set_current_name (save_dialog, docname);
 		g_free (docname);
 	}
@@ -932,7 +933,8 @@ gedit_commands_save_document_async (GeditDocument       *document,
 	GTask *task;
 	GeditTab *tab;
 	GtkSourceFile *file;
-	gchar *uri_for_display;
+	gchar *full_name;
+	GeditStatusbar *statusbar;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -945,7 +947,7 @@ gedit_commands_save_document_async (GeditDocument       *document,
 	tab = gedit_tab_get_from_document (document);
 	file = gedit_document_get_file (document);
 
-	if (gedit_document_is_untitled (document) ||
+	if (_gedit_document_is_untitled (document) ||
 	    gtk_source_file_is_readonly (file))
 	{
 		gedit_debug_message (DEBUG_COMMANDS, "Untitled or Readonly");
@@ -958,13 +960,14 @@ gedit_commands_save_document_async (GeditDocument       *document,
 		return;
 	}
 
-	uri_for_display = _gedit_document_get_uri_for_display (document);
-	gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-				       window->priv->generic_message_cid,
-				       _("Saving file “%s”\342\200\246"),
-				       uri_for_display);
+	full_name = tepl_file_get_full_name (tepl_buffer_get_file (TEPL_BUFFER (document)));
 
-	g_free (uri_for_display);
+	statusbar = GEDIT_STATUSBAR (gedit_window_get_statusbar (window));
+	_gedit_statusbar_flash_generic_message (statusbar,
+						_("Saving file “%s”\342\200\246"),
+						full_name);
+
+	g_free (full_name);
 
 	_gedit_tab_save_async (tab,
 			       cancellable,
@@ -1240,7 +1243,7 @@ save_documents_list (GeditWindow *window,
 
 				/* FIXME: manage the case of local readonly files owned by the
 				   user is running gedit - Paolo (Dec. 8, 2005) */
-				if (gedit_document_is_untitled (doc) ||
+				if (_gedit_document_is_untitled (doc) ||
 				    gtk_source_file_is_readonly (file))
 				{
 					if (data == NULL)
@@ -1283,14 +1286,14 @@ save_documents_list (GeditWindow *window,
 			   - GEDIT_TAB_STATE_CLOSING: this state is invalid in this case
 			*/
 
-			gchar *uri_for_display;
+			gchar *full_name;
 
-			uri_for_display = _gedit_document_get_uri_for_display (doc);
+			full_name = tepl_file_get_full_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 			gedit_debug_message (DEBUG_COMMANDS,
 					     "File '%s' not saved. State: %d",
-					     uri_for_display,
+					     full_name,
 					     state);
-			g_free (uri_for_display);
+			g_free (full_name);
 		}
 	}
 
@@ -1363,16 +1366,17 @@ do_revert (GeditWindow *window,
 {
 	GeditDocument *doc;
 	gchar *docname;
+	GeditStatusbar *statusbar;
 
 	gedit_debug (DEBUG_COMMANDS);
 
 	doc = gedit_tab_get_document (tab);
-	docname = gedit_document_get_short_name_for_display (doc);
+	docname = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 
-	gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-				       window->priv->generic_message_cid,
-				       _("Reverting the document “%s”\342\200\246"),
-				       docname);
+	statusbar = GEDIT_STATUSBAR (gedit_window_get_statusbar (window));
+	_gedit_statusbar_flash_generic_message (statusbar,
+						_("Reverting the document “%s”\342\200\246"),
+						docname);
 
 	g_free (docname);
 
@@ -1417,7 +1421,7 @@ revert_dialog (GeditWindow   *window,
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	docname = gedit_document_get_short_name_for_display (doc);
+	docname = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 	primary_msg = g_strdup_printf (_("Revert unsaved changes to document “%s”?"),
 	                               docname);
 	g_free (docname);
@@ -1549,7 +1553,7 @@ _gedit_cmd_file_revert (GSimpleAction *action,
 
 	doc = gedit_tab_get_document (tab);
 	g_return_if_fail (doc != NULL);
-	g_return_if_fail (!gedit_document_is_untitled (doc));
+	g_return_if_fail (!_gedit_document_is_untitled (doc));
 
 	dialog = revert_dialog (window, doc);
 
@@ -1684,7 +1688,7 @@ save_and_close_documents (GList         *docs,
 
 				/* FIXME: manage the case of local readonly files owned by the
 				 * user is running gedit - Paolo (Dec. 8, 2005) */
-				if (gedit_document_is_untitled (doc) ||
+				if (_gedit_document_is_untitled (doc) ||
 				    gtk_source_file_is_readonly (file))
 				{
 					if (data == NULL)
