@@ -27,6 +27,7 @@
 
 #include "gedit-debug.h"
 #include "gedit-document.h"
+#include "gedit-document-private.h"
 #include "gedit-multi-notebook.h"
 #include "gedit-notebook.h"
 #include "gedit-notebook-popup-menu.h"
@@ -444,7 +445,7 @@ doc_get_name (GeditDocument *doc)
 	gchar *name;
 	gchar *docname;
 
-	name = gedit_document_get_short_name_for_display (doc);
+	name = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 
 	/* Truncate the name so it doesn't get insanely wide. */
 	docname = tepl_utils_str_middle_truncate (name, MAX_DOC_NAME_LENGTH);
@@ -1146,7 +1147,7 @@ panel_on_drag_data_get (GtkWidget        *widget,
 		tab = GEDIT_TAB (GEDIT_DOCUMENTS_DOCUMENT_ROW (panel->drag_document_row)->ref);
 		doc = gedit_tab_get_document (tab);
 
-		if (!gedit_document_is_untitled (doc))
+		if (!_gedit_document_is_untitled (doc))
 		{
 			GtkSourceFile *file = gedit_document_get_file (doc);
 			GFile *location = gtk_source_file_get_location (file);
