@@ -18,52 +18,33 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
+#include "config.h"
 #include "gedit-statusbar.h"
-
-#include <string.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
-
 #include "gedit-app.h"
 #include "gedit-status-menu-button.h"
 
 struct _GeditStatusbar
 {
-	GtkStatusbar  parent_instance;
+	GtkStatusbar parent_instance;
 
-	GtkWidget     *error_frame;
-	GtkWidget     *error_image;
-	GtkWidget     *state_frame;
-	GtkWidget     *load_image;
-	GtkWidget     *save_image;
-	GtkWidget     *print_image;
-	GtkWidget     *overwrite_mode_label;
+	GtkWidget *error_frame;
+	GtkWidget *error_image;
+	GtkWidget *state_frame;
+	GtkWidget *load_image;
+	GtkWidget *save_image;
+	GtkWidget *print_image;
 
 	/* tmp flash timeout data */
-	guint          flash_timeout;
-	guint          flash_context_id;
-	guint          flash_message_id;
+	guint flash_timeout;
+	guint flash_context_id;
+	guint flash_message_id;
+
+	guint generic_message_context_id;
 };
 
 G_DEFINE_TYPE (GeditStatusbar, gedit_statusbar, GTK_TYPE_STATUSBAR)
 
-static gchar *
-get_overwrite_mode_string (gboolean overwrite)
-{
-	/* Use spaces to leave padding proportional to the font size */
-	return g_strdup_printf ("  %s  ", overwrite ? _("OVR") : _("INS"));
-}
-
-static gint
-get_overwrite_mode_length (void)
-{
-	return 4 + MAX (g_utf8_strlen (_("OVR"), -1), g_utf8_strlen (_("INS"), -1));
-}
-
 static void
 gedit_statusbar_dispose (GObject *object)
 {
@@ -95,7 +76,6 @@ gedit_statusbar_class_init (GeditStatusbarClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, GeditStatusbar, load_image);
 	gtk_widget_class_bind_template_child (widget_class, GeditStatusbar, save_image);
 	gtk_widget_class_bind_template_child (widget_class, GeditStatusbar, print_image);
-	gtk_widget_class_bind_template_child (widget_class, GeditStatusbar, overwrite_mode_label);
 }
 
 static void
@@ -103,8 +83,8 @@ gedit_statusbar_init (GeditStatusbar *statusbar)
 {
 	gtk_widget_init_template (GTK_WIDGET (statusbar));
 
-	gtk_label_set_width_chars (GTK_LABEL (statusbar->overwrite_mode_label),
-	                           get_overwrite_mode_length ());
+	statusbar->generic_message_context_id =
+		gtk_statusbar_get_context_id (GTK_STATUSBAR (statusbar), "generic_message");
 }
 
 /**
@@ -113,39 +93,11 @@ gedit_statusbar_init (GeditStatusbar *statusbar)
  * Creates a new #GeditStatusbar.
  *
  * Return value: the new #GeditStatusbar object
- **/
+ */
 GtkWidget *
 gedit_statusbar_new (void)
 {
-	return GTK_WIDGET (g_object_new (GEDIT_TYPE_STATUSBAR, NULL));
-}
-
-/**
- * gedit_statusbar_set_overwrite:
- * @statusbar: a #GeditStatusbar
- * @overwrite: if the overwrite mode is set
- *
- * Sets the overwrite mode on the statusbar.
- **/
-void
-gedit_statusbar_set_overwrite (GeditStatusbar *statusbar,
-                               gboolean        overwrite)
-{
-	gchar *msg;
-
-	g_return_if_fail (GEDIT_IS_STATUSBAR (statusbar));
-
-	msg = get_overwrite_mode_string (overwrite);
-	gtk_label_set_text (GTK_LABEL (statusbar->overwrite_mode_label), msg);
-	g_free (msg);
-}
-
-void
-gedit_statusbar_clear_overwrite (GeditStatusbar *statusbar)
-{
-	g_return_if_fail (GEDIT_IS_STATUSBAR (statusbar));
-
-	gtk_label_set_text (GTK_LABEL (statusbar->overwrite_mode_label), NULL);
+	return g_object_new (GEDIT_TYPE_STATUSBAR, NULL);
 }
 
 static gboolean
@@ -155,9 +107,37 @@ remove_message_timeout (GeditStatusbar *statusbar)
 	                      statusbar->flash_context_id,
 	                      statusbar->flash_message_id);
 
-	/* remove the timeout */
+	/* Remove the timeout. */
 	statusbar->flash_timeout = 0;
-  	return FALSE;
+	return G_SOURCE_REMOVE;
+}
+
+static void
+flash_text (GeditStatusbar *statusbar,
+	    guint           context_id,
+	    const gchar    *text)
+{
+	const guint32 flash_length = 3000; /* Three seconds. */
+
+	/* Remove a currently ongoing flash message. */
+	if (statusbar->flash_timeout > 0)
+	{
+		g_source_remove (statusbar->flash_timeout);
+		statusbar->flash_timeout = 0;
+
+		gtk_statusbar_remove (GTK_STATUSBAR (statusbar),
+				      statusbar->flash_context_id,
+				      statusbar->flash_message_id);
+	}
+
+	statusbar->flash_context_id = context_id;
+	statusbar->flash_message_id = gtk_statusbar_push (GTK_STATUSBAR (statusbar),
+							  context_id,
+							  text);
+
+	statusbar->flash_timeout = g_timeout_add (flash_length,
+						  (GSourceFunc) remove_message_timeout,
+						  statusbar);
 }
 
 /* FIXME this is an issue for introspection */
@@ -176,38 +156,39 @@ gedit_statusbar_flash_message (GeditStatusbar *statusbar,
 			       const gchar    *format,
 			       ...)
 {
-	const guint32 flash_length = 3000; /* three seconds */
 	va_list args;
-	gchar *msg;
+	gchar *text;
 
 	g_return_if_fail (GEDIT_IS_STATUSBAR (statusbar));
 	g_return_if_fail (format != NULL);
 
 	va_start (args, format);
-	msg = g_strdup_vprintf (format, args);
+	text = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	/* remove a currently ongoing flash message */
-	if (statusbar->flash_timeout > 0)
-	{
-		g_source_remove (statusbar->flash_timeout);
-		statusbar->flash_timeout = 0;
+	flash_text (statusbar, context_id, text);
 
-		gtk_statusbar_remove (GTK_STATUSBAR (statusbar),
-		                      statusbar->flash_context_id,
-		                      statusbar->flash_message_id);
-	}
+	g_free (text);
+}
 
-	statusbar->flash_context_id = context_id;
-	statusbar->flash_message_id = gtk_statusbar_push (GTK_STATUSBAR (statusbar),
-							  context_id,
-							  msg);
+void
+_gedit_statusbar_flash_generic_message (GeditStatusbar *statusbar,
+					const gchar    *format,
+					...)
+{
+	va_list args;
+	gchar *text;
 
-	statusbar->flash_timeout = g_timeout_add (flash_length,
-						  (GSourceFunc) remove_message_timeout,
-						  statusbar);
+	g_return_if_fail (GEDIT_IS_STATUSBAR (statusbar));
+	g_return_if_fail (format != NULL);
 
-	g_free (msg);
+	va_start (args, format);
+	text = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	flash_text (statusbar, statusbar->generic_message_context_id, text);
+
+	g_free (text);
 }
 
 void
