@@ -248,7 +248,7 @@ update_auto_save_timeout (GeditTab *tab)
 
 	if (tab->state == GEDIT_TAB_STATE_NORMAL &&
 	    tab->auto_save &&
-	    !gedit_document_is_untitled (doc) &&
+	    !_gedit_document_is_untitled (doc) &&
 	    !gtk_source_file_is_readonly (file))
 	{
 		install_auto_save_timeout (tab);
@@ -757,7 +757,7 @@ show_loading_info_bar (GTask *loading_task)
 
 	doc = gedit_tab_get_document (data->tab);
 
-	name = gedit_document_get_short_name_for_display (doc);
+	name = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 	len = g_utf8_strlen (name, -1);
 
 	/* if the name is awfully long, truncate it and be done with it,
@@ -871,9 +871,7 @@ show_saving_info_bar (GTask *saving_task)
 	gedit_debug (DEBUG_TAB);
 
 	doc = gedit_tab_get_document (tab);
-
-	short_name = gedit_document_get_short_name_for_display (doc);
-
+	short_name = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 	len = g_utf8_strlen (short_name, -1);
 
 	/* if the name is awfully long, truncate it and be done with it,
@@ -1434,8 +1432,7 @@ _gedit_tab_get_name (GeditTab *tab)
 	g_return_val_if_fail (GEDIT_IS_TAB (tab), NULL);
 
 	doc = gedit_tab_get_document (tab);
-
-	name = gedit_document_get_short_name_for_display (doc);
+	name = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 
 	/* Truncate the name so it doesn't get insanely wide. */
 	docname = tepl_utils_str_middle_truncate (name, MAX_DOC_NAME_LENGTH);
@@ -1459,22 +1456,15 @@ gchar *
 _gedit_tab_get_tooltip (GeditTab *tab)
 {
 	GeditDocument *doc;
+	gchar *full_name;
+	gchar *full_name_markup;
 	gchar *tip;
-	gchar *uri;
-	gchar *ruri;
-	gchar *ruri_markup;
 
 	g_return_val_if_fail (GEDIT_IS_TAB (tab), NULL);
 
 	doc = gedit_tab_get_document (tab);
-
-	uri = _gedit_document_get_uri_for_display (doc);
-	g_return_val_if_fail (uri != NULL, NULL);
-
-	ruri = 	tepl_utils_replace_home_dir_with_tilde (uri);
-	g_free (uri);
-
-	ruri_markup = g_markup_printf_escaped ("<i>%s</i>", ruri);
+	full_name = tepl_file_get_full_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
+	full_name_markup = g_markup_printf_escaped ("<i>%s</i>", full_name);
 
 	switch (tab->state)
 	{
@@ -1487,19 +1477,17 @@ _gedit_tab_get_tooltip (GeditTab *tab)
 		const GtkSourceEncoding *enc;
 
 		case GEDIT_TAB_STATE_LOADING_ERROR:
-			tip = g_strdup_printf (_("Error opening file %s"),
-					       ruri_markup);
+			tip = g_strdup_printf (_("Error opening file %s"), full_name_markup);
 			break;
 
 		case GEDIT_TAB_STATE_REVERTING_ERROR:
-			tip = g_strdup_printf (_("Error reverting file %s"),
-					       ruri_markup);
+			tip = g_strdup_printf (_("Error reverting file %s"), full_name_markup);
 			break;
 
 		case GEDIT_TAB_STATE_SAVING_ERROR:
-			tip =  g_strdup_printf (_("Error saving file %s"),
-						ruri_markup);
+			tip =  g_strdup_printf (_("Error saving file %s"), full_name_markup);
 			break;
+
 		default:
 			content_type = gedit_document_get_content_type (doc);
 			mime_type = gedit_document_get_mime_type (doc);
@@ -1528,7 +1516,7 @@ _gedit_tab_get_tooltip (GeditTab *tab)
 			tip =  g_markup_printf_escaped ("<b>%s</b> %s\n\n"
 						        "<b>%s</b> %s\n"
 						        "<b>%s</b> %s",
-						        _("Name:"), ruri,
+						        _("Name:"), full_name,
 						        _("MIME Type:"), content_full_description,
 						        _("Encoding:"), encoding);
 
@@ -1537,9 +1525,8 @@ _gedit_tab_get_tooltip (GeditTab *tab)
 			break;
 	}
 
-	g_free (ruri);
-	g_free (ruri_markup);
-
+	g_free (full_name);
+	g_free (full_name_markup);
 	return tip;
 }
 
@@ -2311,8 +2298,7 @@ save_cb (GtkSourceFileSaver *saver,
 		    error->code == GTK_SOURCE_FILE_SAVER_ERROR_EXTERNALLY_MODIFIED)
 		{
 			/* This error is recoverable */
-			info_bar = gedit_externally_modified_saving_error_info_bar_new (location);
-			g_return_if_fail (info_bar != NULL);
+			info_bar = GTK_WIDGET (tepl_io_error_info_bar_saving_externally_modified (location));
 
 			g_signal_connect (info_bar,
 					  "response",
@@ -2486,7 +2472,7 @@ _gedit_tab_save_async (GeditTab            *tab,
 	}
 
 	doc = gedit_tab_get_document (tab);
-	g_return_if_fail (!gedit_document_is_untitled (doc));
+	g_return_if_fail (!_gedit_document_is_untitled (doc));
 
 	saving_task = g_task_new (tab, cancellable, callback, user_data);
 
@@ -2544,7 +2530,7 @@ gedit_tab_auto_save (GeditTab *tab)
 	doc = gedit_tab_get_document (tab);
 	file = gedit_document_get_file (doc);
 
-	g_return_val_if_fail (!gedit_document_is_untitled (doc), G_SOURCE_REMOVE);
+	g_return_val_if_fail (!_gedit_document_is_untitled (doc), G_SOURCE_REMOVE);
 	g_return_val_if_fail (!gtk_source_file_is_readonly (file), G_SOURCE_REMOVE);
 
 	if (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)))
@@ -2705,9 +2691,8 @@ get_print_settings (GeditTab *tab)
 	 */
 	gtk_print_settings_set (settings, GTK_PRINT_SETTINGS_OUTPUT_URI, NULL);
 
-	name = gedit_document_get_short_name_for_display (doc);
+	name = tepl_file_get_short_name (tepl_buffer_get_file (TEPL_BUFFER (doc)));
 	gtk_print_settings_set (settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME, name);
-
 	g_free (name);
 
 	return settings;
@@ -2877,7 +2862,7 @@ _gedit_tab_print (GeditTab *tab)
 
 	view = gedit_tab_get_view (tab);
 
-	tab->print_job = gedit_print_job_new (view);
+	tab->print_job = gedit_print_job_new (TEPL_VIEW (view));
 
 	add_printing_info_bar (tab);
 
